@@ -1,5 +1,7 @@
 # frozen_string_literal: true
 
+# rbs_inline: enabled
+
 #
 # Gruff::AccumulatorBar is a special bar graph that shows a
 # single dataset as a set of stacked bars.
@@ -19,7 +21,7 @@ private
   def setup_data
     raise(Gruff::IncorrectNumberOfDatasetsException) unless store.length == 1
 
-    accum_array = store.data.first.points[0..-2].reduce([0]) { |a, v| a << (a.last + v) }
+    accum_array = store.data.first.points[0..-2].reduce([0]) { |a, v| a << (a.last + v.to_f) } # steep:ignore
     data 'Accumulator', accum_array
     set_colors
     store.reverse!
